<?php

namespace Litecms\Leadmanagement\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Litecms\Leadmanagement\Http\Requests\LeadmanagementRequest;
use Litecms\Leadmanagement\Interfaces\LeadmanagementRepositoryInterface;
use Litecms\Leadmanagement\Models\Leadmanagement;

/**
 * Resource controller class for leadmanagement.
 */
class LeadmanagementResourceController extends BaseController
{

    /**
     * Initialize leadmanagement resource controller.
     *
     * @param type LeadmanagementRepositoryInterface $leadmanagement
     *
     * @return null
     */
    public function __construct(LeadmanagementRepositoryInterface $leadmanagement)
    {
        parent::__construct();
        $this->repository = $leadmanagement;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Litecms\Leadmanagement\Repositories\Criteria\LeadmanagementResourceCriteria::class);
    }

    /**
     * Display a list of leadmanagement.
     *
     * @return Response
     */
    public function index(LeadmanagementRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Litecms\Leadmanagement\Repositories\Presenter\LeadmanagementPresenter::class)
                ->$function();
        }

        $leadmanagements = $this->repository->paginate();

        return $this->response->title(trans('leadmanagement::leadmanagement.names'))
            ->view('leadmanagement::leadmanagement.index', true)
            ->data(compact('leadmanagements'))
            ->output();
    }

    /**
     * Display leadmanagement.
     *
     * @param Request $request
     * @param Model   $leadmanagement
     *
     * @return Response
     */
    public function show(LeadmanagementRequest $request, Leadmanagement $leadmanagement)
    {

        if ($leadmanagement->exists) {
            $view = 'leadmanagement::leadmanagement.show';
        } else {
            $view = 'leadmanagement::leadmanagement.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('leadmanagement::leadmanagement.name'))
            ->data(compact('leadmanagement'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new leadmanagement.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(LeadmanagementRequest $request)
    {

        $leadmanagement = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('leadmanagement::leadmanagement.name')) 
            ->view('leadmanagement::leadmanagement.create', true) 
            ->data(compact('leadmanagement'))
            ->output();
    }

    /**
     * Create new leadmanagement.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LeadmanagementRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $leadmanagement                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('leadmanagement::leadmanagement.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('leadmanagement/leadmanagement/' . $leadmanagement->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/leadmanagement/leadmanagement'))
                ->redirect();
        }

    }

    /**
     * Show leadmanagement for editing.
     *
     * @param Request $request
     * @param Model   $leadmanagement
     *
     * @return Response
     */
    public function edit(LeadmanagementRequest $request, Leadmanagement $leadmanagement)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('leadmanagement::leadmanagement.name'))
            ->view('leadmanagement::leadmanagement.edit', true)
            ->data(compact('leadmanagement'))
            ->output();
    }

    /**
     * Update the leadmanagement.
     *
     * @param Request $request
     * @param Model   $leadmanagement
     *
     * @return Response
     */
    public function update(LeadmanagementRequest $request, Leadmanagement $leadmanagement)
    {
        try {
            $attributes = $request->all();

            $leadmanagement->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('leadmanagement::leadmanagement.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('leadmanagement/leadmanagement/' . $leadmanagement->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('leadmanagement/leadmanagement/' . $leadmanagement->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the leadmanagement.
     *
     * @param Model   $leadmanagement
     *
     * @return Response
     */
    public function destroy(LeadmanagementRequest $request, Leadmanagement $leadmanagement)
    {
        try {

            $leadmanagement->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('leadmanagement::leadmanagement.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('leadmanagement/leadmanagement/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('leadmanagement/leadmanagement/' . $leadmanagement->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple leadmanagement.
     *
     * @param Model   $leadmanagement
     *
     * @return Response
     */
    public function delete(LeadmanagementRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('leadmanagement::leadmanagement.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('leadmanagement/leadmanagement'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/leadmanagement/leadmanagement'))
                ->redirect();
        }

    }

    /**
     * Restore deleted leadmanagements.
     *
     * @param Model   $leadmanagement
     *
     * @return Response
     */
    public function restore(LeadmanagementRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('leadmanagement::leadmanagement.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/leadmanagement/leadmanagement'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/leadmanagement/leadmanagement/'))
                ->redirect();
        }

    }

}
