<?php

namespace Litecms\Leadmanagement\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Leadmanagement\Models\Leadmanagement;

class LeadmanagementPolicy
{

    /**
     * Determine if the given user can view the leadmanagement.
     *
     * @param UserPolicy $user
     * @param Leadmanagement $leadmanagement
     *
     * @return bool
     */
    public function view(UserPolicy $user, Leadmanagement $leadmanagement)
    {
        if ($user->canDo('leadmanagement.leadmanagement.view') && $user->isAdmin()) {
            return true;
        }

        return $leadmanagement->user_id == user_id() && $leadmanagement->user_type == user_type();
    }

    /**
     * Determine if the given user can create a leadmanagement.
     *
     * @param UserPolicy $user
     * @param Leadmanagement $leadmanagement
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('leadmanagement.leadmanagement.create');
    }

    /**
     * Determine if the given user can update the given leadmanagement.
     *
     * @param UserPolicy $user
     * @param Leadmanagement $leadmanagement
     *
     * @return bool
     */
    public function update(UserPolicy $user, Leadmanagement $leadmanagement)
    {
        if ($user->canDo('leadmanagement.leadmanagement.edit') && $user->isAdmin()) {
            return true;
        }

        return $leadmanagement->user_id == user_id() && $leadmanagement->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given leadmanagement.
     *
     * @param UserPolicy $user
     * @param Leadmanagement $leadmanagement
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Leadmanagement $leadmanagement)
    {
        return $leadmanagement->user_id == user_id() && $leadmanagement->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given leadmanagement.
     *
     * @param UserPolicy $user
     * @param Leadmanagement $leadmanagement
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Leadmanagement $leadmanagement)
    {
        if ($user->canDo('leadmanagement.leadmanagement.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given leadmanagement.
     *
     * @param UserPolicy $user
     * @param Leadmanagement $leadmanagement
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Leadmanagement $leadmanagement)
    {
        if ($user->canDo('leadmanagement.leadmanagement.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
