<?php

namespace Litecms\Leadmanagement\Providers;

use Illuminate\Support\ServiceProvider;

class LeadmanagementServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'leadmanagement');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'leadmanagement');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.leadmanagement', function ($app) {
            return $this->app->make('Litecms\Leadmanagement\Leadmanagement');
        });

                // Bind Leadmanagement to repository
        $this->app->bind(
            'Litecms\Leadmanagement\Interfaces\LeadmanagementRepositoryInterface',
            \Litecms\Leadmanagement\Repositories\Eloquent\LeadmanagementRepository::class
        );

        $this->app->register(\Litecms\Leadmanagement\Providers\AuthServiceProvider::class);
        
        $this->app->register(\Litecms\Leadmanagement\Providers\RouteServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.leadmanagement'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/leadmanagement.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/leadmanagement')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/leadmanagement')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
